      SUBROUTINE MCLR(MATXI,MROW,NCOL)
C
C***********************************************************************
C
C   NAME- MCLR
C
C   LANGUAGE- FORTRAN 77    TYPE- SUBROUTINE      COMPUTER- CRAY     
C
C   VERSION- 1.0    DATE- 07/06/89   PROGRAMMER- G. RAJASHEKAR (SMSRC)
C   VERSION- 3.0    DATE- 05/09/96   PROGRAMMER- A. POZDNYAK (FDC)    
C      MODIFIED TO RUN ON THE CRAY.  REPLACED I*4 WITH INT AND
C      R*4 WITH REAL.
C  
C   FUNCTION - THIS SUBROUTINE WILL CLEAR (ZERO) ALL THE ELEMENTS OF THE
C              INPUT MATRIX AND RETURN THE RESULTANT MATRIX AS THE
C              OUTPUT.
C
C   CALLING SEQUENCE PARAMETERS-
C
C   NAME     TYPE    I/O     FUNCTION
C
C   MATXI    REAL    I/O     REAL MATRIX OF DIMENSION MROW * NCOL
C   MROW     INT      I      NUMBER OF ROWS IN THE INPUT & OUTPUT MATRIX
C   NCOL     INT      I      NUMBER OF COLS IN THE INPUT & OUTPUT MATRIX
C
      INTEGER   MROW,NCOL
      REAL      MATXI(MROW,NCOL)
C
C   LOCAL PARAMETERS-
C
C   NAME     TYPE    FUNCTION
C
C   I, J     INT     DO LOOP INDICES
C
      INTEGER   I,J
C
C***********************************************************************
C
      DO 300 J = 1,NCOL
         DO 200 I = 1,MROW
            MATXI(I,J) = 0.
  200    CONTINUE
  300 CONTINUE
C
      RETURN
      END
